==> sui-tool-task-manager-1.8.0.tgz: package/lib/domain/task/Entities/WorkTaskEntity.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import { Entity } from '@s-ui/domain';
export var WorkTaskEntity = /*#__PURE__*/function (_Entity) {
  _inheritsLoose(WorkTaskEntity, _Entity);
  function WorkTaskEntity(_ref) {
    var config = _ref.config,
      createdAt = _ref.createdAt,
      finishedAt = _ref.finishedAt,
      id = _ref.id,
      log = _ref.log,
      name = _ref.name,
      onComplete = _ref.onComplete,
      onError = _ref.onError,
      parentId = _ref.parentId,
      percentage = _ref.percentage,
      result = _ref.result,
      retryAttempts = _ref.retryAttempts,
      start = _ref.start,
      status = _ref.status,
      taskId = _ref.taskId,
      updatedAt = _ref.updatedAt;
    return _Entity.call(this, {
      config: config,
      createdAt: createdAt,
      finishedAt: finishedAt,
      id: id,
      log: log,
      name: name,
      onComplete: onComplete,
      onError: onError,
      parentId: parentId,
      percentage: percentage,
      result: result,
      retryAttempts: retryAttempts,
      start: start,
      status: status,
      taskId: taskId,
      updatedAt: updatedAt
    }) || this;
  }
  var _proto = WorkTaskEntity.prototype;
  _proto.isInProgress = function isInProgress() {
    if (this._status.getValue() === this._config.get('AVAILABLE_STATUS').IN_PROGRESS) return true;
    return false;
  };
  _proto.isCompleted = function isCompleted() {
    if (this._status.getValue() === this._config.get('AVAILABLE_STATUS').COMPLETED) return true;
    return false;
  };
  _proto.isQueued = function isQueued() {
    if (this._status.getValue() === this._config.get('AVAILABLE_STATUS').QUEUED) return true;
    return false;
  };
  _proto.areDependenciesMet = function areDependenciesMet(siblingWorkList) {
    if (this._parentId.get() === null) return true;
    var parent = siblingWorkList.getById(this._parentId);
    if (parent === undefined || parent.isCompleted()) return true;
    return false;
  };
  _proto.retry = function retry() {
    this._retryAttempts.decreaseBy(1);
    this._percentage.set(0);
    this._status.setQueued();
  };
  _proto.markAsError = function markAsError(log) {
    this._log.set(log);
    if (this._retryAttempts.get() > 0) return this.retry();
    this._status.setError();
    this._finishedAt.setNow();
    var errorCallback = this._onError.get();
    errorCallback(this.toJSON());
  };
  _proto.markAsCompleted = function markAsCompleted(result) {
    this._status.setCompleted();
    this._percentage.set(100);
    this._finishedAt.setNow();
    this._result.set(result);
    var callback = this._onComplete.get();
    callback(this.toJSON());
  };
  _proto.execute = function execute() {
    this._status.setInProgress();
    var startCallback = this._start.get();
    startCallback(this.toJSON());
  };
  _proto.toJSON = function toJSON() {
    return {
      createdAt: this._createdAt.toJSON(),
      finishedAt: this._finishedAt.toJSON(),
      id: this._id.toJSON(),
      log: this._log.toJSON(),
      name: this._name.toJSON(),
      onComplete: this._onComplete.toJSON(),
      onError: this._onError.toJSON(),
      parentId: this._parentId.toJSON(),
      percentage: this._percentage.toJSON(),
      result: this._result.toJSON(),
      retryAttempts: this._retryAttempts.toJSON(),
      start: this._start.toJSON(),
      status: this._status.toJSON(),
      taskId: this._taskId.toJSON(),
      updatedAt: this._updatedAt.toJSON()
    };
  };
  return WorkTaskEntity;
}(Entity);

==> sui-tool-task-manager-1.16.0.tgz: package/lib/domain/task/Entities/WorkTaskEntity.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import { Entity } from '@s-ui/domain';
export var WorkTaskEntity = /*#__PURE__*/function (_Entity) {
  _inheritsLoose(WorkTaskEntity, _Entity);
  function WorkTaskEntity(_ref) {
    var config = _ref.config,
      createdAt = _ref.createdAt,
      finishedAt = _ref.finishedAt,
      id = _ref.id,
      isVisible = _ref.isVisible,
      log = _ref.log,
      name = _ref.name,
      onComplete = _ref.onComplete,
      onError = _ref.onError,
      parentId = _ref.parentId,
      percentage = _ref.percentage,
      result = _ref.result,
      retryAttempts = _ref.retryAttempts,
      start = _ref.start,
      status = _ref.status,
      taskId = _ref.taskId,
      updatedAt = _ref.updatedAt;
    return _Entity.call(this, {
      config: config,
      createdAt: createdAt,
      finishedAt: finishedAt,
      id: id,
      isVisible: isVisible,
      log: log,
      name: name,
      onComplete: onComplete,
      onError: onError,
      parentId: parentId,
      percentage: percentage,
      result: result,
      retryAttempts: retryAttempts,
      start: start,
      status: status,
      taskId: taskId,
      updatedAt: updatedAt
    }) || this;
  }
  var _proto = WorkTaskEntity.prototype;
  _proto.isInProgress = function isInProgress() {
    if (this._status.getValue() === this._config.get('AVAILABLE_STATUS').IN_PROGRESS) return true;
    return false;
  };
  _proto.isCompleted = function isCompleted() {
    if (this._status.getValue() === this._config.get('AVAILABLE_STATUS').COMPLETED) return true;
    return false;
  };
  _proto.isQueued = function isQueued() {
    if (this._status.getValue() === this._config.get('AVAILABLE_STATUS').QUEUED) return true;
    return false;
  };
  _proto.isVisible = function isVisible() {
    return this._isVisible;
  };
  _proto.areDependenciesMet = function areDependenciesMet(siblingWorkList) {
    if (this._parentId.isEmpty()) return true;
    var parent = siblingWorkList.getById(this._parentId);
    if (parent === undefined || parent.isCompleted()) return true;
    return false;
  };
  _proto.retry = function retry() {
    this._retryAttempts.decreaseBy(1);
    this._percentage.set(0);
    this._status.setQueued();
  };
  _proto.markAsError = function markAsError(log) {
    this._log.set(log);
    if (this._retryAttempts.get() > 0) return this.retry();
    this._status.setError();
    this._finishedAt.setNow();
    var errorCallback = this._onError.get();
    errorCallback(this.toJSON());
  };
  _proto.markAsCompleted = function markAsCompleted(result) {
    this._status.setCompleted();
    this._percentage.set(100);
    this._finishedAt.setNow();
    this._result.set(result);
    var callback = this._onComplete.get();
    callback(this.toJSON());
  };
  _proto.execute = function execute() {
    this._status.setInProgress();
    var startCallback = this._start.get();
    startCallback(this.toJSON());
  };
  _proto.toJSON = function toJSON() {
    return {
      createdAt: this._createdAt.toJSON(),
      finishedAt: this._finishedAt.toJSON(),
      id: this._id.toJSON(),
      isVisible: this._isVisible,
      log: this._log.toJSON(),
      name: this._name.toJSON(),
      onComplete: this._onComplete.toJSON(),
      onError: this._onError.toJSON(),
      parentId: this._parentId.toJSON(),
      percentage: this._percentage.toJSON(),
      result: this._result.toJSON(),
      retryAttempts: this._retryAttempts.toJSON(),
      start: this._start.toJSON(),
      status: this._status.toJSON(),
      taskId: this._taskId.toJSON(),
      updatedAt: this._updatedAt.toJSON()
    };
  };
  return WorkTaskEntity;
}(Entity);
